<?php
/**
 * WooCommerce Compatibility File.
 *
 * @link https://woocommerce.com/
 *
 * @package Karuna
 */

/**
 * WooCommerce setup function.
 */
function karuna_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'karuna_woocommerce_setup' );

/**
 * Output Custom WooCommerce content.
 */
function woocommerce_content() {
	if ( is_singular( 'product' ) ) {

		while ( have_posts() ) : the_post();
			wc_get_template_part( 'content', 'single-product' );
		endwhile;

	} else {

		if ( apply_filters( 'woocommerce_show_page_title', true ) ) {

			echo '<h1 class="entry-title">';
				woocommerce_page_title();
			echo '</h1>';

		}

		do_action( 'woocommerce_archive_description' );

		if ( have_posts() ) {

			do_action( 'woocommerce_before_shop_loop' );
			woocommerce_product_loop_start();
			woocommerce_product_subcategories();

			while ( have_posts() ) : the_post();
				wc_get_template_part( 'content', 'product' );
			endwhile;

			woocommerce_product_loop_end();
			do_action( 'woocommerce_after_shop_loop' );

		} elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) {

			do_action( 'woocommerce_no_products_found' );

		}
	}
}

if ( ! function_exists( 'karuna_woocommerce_image_dimensions' ) ) :
/**
 * Define image sizes
 */
function karuna_woocommerce_image_dimensions() {
	global $pagenow;

	if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
		return;
	}

	$catalog = array(
		'width'  => '692',
		'height' => '692',
		'crop'	 => 1,
	);
	$single = array(
		'width'  => '692',
		'height' => '692',
		'crop'   => 1,
	);
	$thumbnail = array(
		'width'  => '154',
		'height' => '154',
		'crop'   => 0,
	);

	update_option( 'shop_catalog_image_size', $catalog );
	update_option( 'shop_single_image_size', $single );
	update_option( 'shop_thumbnail_image_size', $thumbnail );
}
add_action( 'after_switch_theme', 'karuna_woocommerce_image_dimensions', 1 );
endif;

if ( ! function_exists( 'karuna_woocommerce_loop_columns' ) ) :
/**
 * Change number of products per row to 2.
 */
function karuna_woocommerce_loop_columns() {
	return 2;
}
add_filter( 'loop_shop_columns', 'karuna_woocommerce_loop_columns' );
endif;

if ( ! function_exists( 'karuna_woocommerce_related_products' ) ) :
/**
 * Change number of related products per row to 2 and number of products to 2.
 */
function karuna_woocommerce_related_products( $args ) {
	$args['posts_per_page'] = 2;
	$args['columns'] = 2;
	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'karuna_woocommerce_related_products' );
endif;

if ( ! function_exists( 'karuna_woocommerce_product_thumbnails_columns' ) ) :
/**
 * Change number of thumbnails per row in product galleries to 4.
 */
function karuna_woocommerce_product_thumbnails_columns() {
	return 4;
}
add_filter ( 'woocommerce_product_thumbnails_columns', 'karuna_woocommerce_product_thumbnails_columns' );
endif;

/**
 * Reorganize single product.
 */
function karuna_woocommerce_image_wrapper_open() {
	echo '<div class="woocommerce-image-wrapper">';
}

function karuna_woocommerce_image_wrapper_closed() {
	echo '</div>';
}

add_action( 'woocommerce_before_single_product_summary', 'woocommerce_template_single_title', 1 );
add_action( 'woocommerce_before_single_product_summary', 'woocommerce_template_single_rating', 2 );
add_action( 'woocommerce_before_single_product_summary', 'woocommerce_template_single_price', 2 );
add_action( 'woocommerce_before_single_product_summary', 'karuna_woocommerce_image_wrapper_open', 5 );
add_action( 'woocommerce_before_single_product_summary', 'karuna_woocommerce_image_wrapper_closed', 25 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
